# MAVEN Dataset (English to Portuguese)

This folder contains the MAVEN dataset translated from English into Portuguese.

## Description

MAVEN is one of the largest event detection corpora with 118,732 event mentions over 4,480 Wikipedia documents, annotated with 168 event types based on FrameNet extensions.

## Translation Details

* Original language: English
* Translated to: Portuguese
* Translation approach: Automatic machine translation followed by annotation alignment using LinguAligner.

## Reference

Wang, Xiaozhi, Wang, Ziqi, Han, Xu, Jiang, Wangyi, Han, Rong, Liu, Zhiyuan, Li, Juanzi, Li, Peng, Lin, Yankai, & Zhou, Jie. (2020). **MAVEN: A Massive General Domain Event Detection Dataset**. *Proceedings of the 2020 Conference on Empirical Methods in Natural Language Processing (EMNLP)*, 1652–1671. Association for Computational Linguistics. [https://doi.org/10.18653/v1/2020.emnlp-main.129](https://doi.org/10.18653/v1/2020.emnlp-main.129)